import useSWR from "swr";
import { enqueueSnackbar } from "notistack";

import { getDiscounts } from "./requests";

export function useDiscounts() {
	const { data } = useSWR(
		"discounts",
		async () => {
			const [discounts, discountsError] = await getDiscounts();

			if (discountsError || !discounts) {
				throw new Error(discountsError);
			}

			return discounts;
		},
		{
			keepPreviousData: true,
			suspense: true,
			onError: (error) => {
				if (!(error instanceof Error)) return;

				enqueueSnackbar(error.message, { variant: "error" });
			},
		}
	);

	return data;
}
