import makeRequest from "@root/api/makeRequest";

import { parseAxiosError } from "@root/utils/parse-error";

type RawDetail = {
	Key: string;
	Value: number | string | RawDetail[];
};

type History = {
	id: string;
	userId: string;
	comment: string;
	key: string;
	rawDetails: RawDetail[];
	isDeleted: boolean;
	createdAt: string;
	updatedAt: string;
};

type HistoryResponse = {
	records: History[];
	totalPages: number;
};

const API_URL = `${process.env.REACT_APP_DOMAIN}/customer/v1.0.1`;

const getUserHistory = async (accountId: string, page: number): Promise<[HistoryResponse | null, string?]> => {
	try {
		const historyResponse = await makeRequest<never, HistoryResponse>({
			method: "GET",
			url: `${API_URL}/history?page=${page}&limit=${100}&accountID=${accountId}&type=payCart`,
		});

		return [historyResponse];
	} catch (nativeError) {
		const [error] = parseAxiosError(nativeError);

		return [null, `Ошибка при получении пользователей. ${error}`];
	}
};

export const historyApi = {
	getUserHistory,
};
