import makeRequest from "@root/api/makeRequest";
import { parseAxiosError } from "@root/utils/parse-error";

import type {
	GetStatisticSchildBody,
	QuizStatisticsItem,
	GetPromocodeStatisticsBody,
	AllPromocodeStatistics,
} from "./types";

export type QuizStatisticResponse = {
	Registrations: number;
	Quizes: number;
	Results: number;
};

type TRequest = {
	to: number;
	from: number;
};

const API_URL = process.env.REACT_APP_DOMAIN;

export const getStatistic = async (to: number, from: number): Promise<[QuizStatisticResponse | null, string?]> => {
	try {
		const generalResponse = await makeRequest<TRequest, QuizStatisticResponse>({
			url: `${API_URL}/squiz/statistic`,
			body: { to, from },
		});

		return [generalResponse];
	} catch (nativeError) {
		const [error] = parseAxiosError(nativeError);

		return [null, `Не удалось получить статистику ${error}`];
	}
};

export const getStatisticSchild = async (from: number, to: number): Promise<[QuizStatisticsItem[] | null, string?]> => {
	try {
		const statisticResponse = await makeRequest<GetStatisticSchildBody, QuizStatisticsItem[]>({
			method: "POST",
			url: `${API_URL}/customer/v1.0.1/quizlogo/stat`,
			body: { to, from, page: 0, limit: 100 },
			useToken: true,
		});

		if (!statisticResponse) {
			return [null, "Статистика не найдена"];
		}

		return [statisticResponse];
	} catch (nativeError) {
		const [error] = parseAxiosError(nativeError);

		return [
			[
				{
					ID: "0",
					Regs: 0,
					Money: 0,
					Quizes: [{ QuizID: "0", Regs: 0, Money: 0 }],
				},
			],
			`Не удалось получить статистику ${error}`,
		];
	}
};

export const getStatisticsPromocode = async (
	from: number,
	to: number
): Promise<[Record<string, AllPromocodeStatistics> | null, string?]> => {
	try {
		const statisticsPromocode = await makeRequest<GetPromocodeStatisticsBody, Record<string, AllPromocodeStatistics>>({
			method: "POST",
			url: `${API_URL}/customer/v1.0.1/promocode/ltv`,
			body: { to, from },
			useToken: true,
		});

		return [statisticsPromocode];
	} catch (nativeError) {
		const error = parseAxiosError(nativeError);

		return [null, `Не удалось получить статистику промокода ${error}`];
	}
};
