import makeRequest from "@root/api/makeRequest";

import { parseAxiosError } from "@root/utils/parse-error";

export const MOCK_DATA_USERS = [
	{
		key: 0,
		id: "someid1",
		name: "admin",
		desc: "Администратор сервиса",
	},
	{
		key: 1,
		id: "someid2",
		name: "manager",
		desc: "Менеджер сервиса",
	},
	{
		key: 2,
		id: "someid3",
		name: "user",
		desc: "Пользователь сервиса",
	},
];

export type TMockData = typeof MOCK_DATA_USERS;

export type UserType = {
	_id: string;
	login: string;
	email: string;
	phoneNumber: string;
	isDeleted: boolean;
	createdAt: string;
	updatedAt: string;
};

const API_URL = `${process.env.REACT_APP_DOMAIN}/role`;

export const getRoles_mock = (): Promise<TMockData> => {
	return new Promise((resolve) => {
		setTimeout(() => {
			resolve(MOCK_DATA_USERS);
		}, 1000);
	});
};

export const deleteRole = async (id: string): Promise<[unknown, string?]> => {
	try {
		const deleteRoleResponse = await makeRequest<never, unknown>({
			method: "DELETE",
			url: `${API_URL}/${id}`,
		});

		return [deleteRoleResponse];
	} catch (nativeError) {
		const [error] = parseAxiosError(nativeError);

		return [null, `Ошибка удаления роли. ${error}`];
	}
};
