import makeRequest from "@root/api/makeRequest";

import { parseAxiosError } from "@root/utils/parse-error";

import type { SendTicketMessageRequest } from "@root/model/ticket";

const API_URL = `${process.env.REACT_APP_DOMAIN}/heruvym/v1.0.0`;

type CloseTicketBody = {
	ticket: string;
};

type SendFileResponse = {
	message: string;
};

export const sendTicketMessage = async (body: SendTicketMessageRequest): Promise<[null, string?]> => {
	try {
		const sendTicketMessageResponse = await makeRequest<SendTicketMessageRequest, null>({
			method: "POST",
			url: `${API_URL}/send`,
			body,
			useToken: true,
		});

		return [sendTicketMessageResponse];
	} catch (nativeError) {
		const [error] = parseAxiosError(nativeError);

		return [null, `Ошибка отправки сообщения. ${error}`];
	}
};

export const closeTicket = async (ticketId: string): Promise<[CloseTicketBody | null, string?]> => {
	try {
		const ticketCloseResponse = await makeRequest<CloseTicketBody, CloseTicketBody>({
			method: "POST",
			url: `${API_URL}/close`,
			body: { ticket: ticketId },
			useToken: true,
		});

		return [ticketCloseResponse];
	} catch (nativeError) {
		const [error] = parseAxiosError(nativeError);

		return [null, `Не удалось закрыть тикет. ${error}`];
	}
};

export const sendFile = async (file: File, ticketId: string): Promise<[SendFileResponse | null, string?]> => {
	try {
		const body = new FormData();
		body.append(file.name, file);
		body.append("ticket", ticketId);

		const sendFileRespose = await makeRequest<FormData, SendFileResponse>({
			method: "POST",
			url: `${API_URL}/sendFiles`,
			body,
		});

		return [sendFileRespose];
	} catch (nativeError) {
		const [error] = parseAxiosError(nativeError);

		return [null, `Не удалось отправить файл. ${error}`];
	}
};
