import makeRequest from "@root/api/makeRequest";

import { parseAxiosError } from "@root/utils/parse-error";

type File = {
	name: "inn" | "rule" | "egrule" | "certificate";
	url: string;
};

export type Verification = {
	_id: string;
	accepted: boolean;
	status: "org" | "nko";
	updated_at: string;
	comment: string;
	taxnumber: string;
	files: File[];
};

type PatchVerificationBody = {
	id?: string;
	status?: "org" | "nko";
	comment?: string;
	accepted?: boolean;
	taxnumber?: string;
};

const API_URL = `${process.env.REACT_APP_DOMAIN}/verification/v1.0.0`;

export const verification = async (userId: string): Promise<[Verification | null, string?]> => {
	try {
		const verificationResponse = await makeRequest<never, Verification>({
			method: "GET",
			url: `${API_URL}/verification/${userId}`,
		});

		return [verificationResponse];
	} catch (nativeError) {
		const [error] = parseAxiosError(nativeError);

		return [null, `Ошибка верификации. ${error}`];
	}
};

export const patchVerification = async (body: PatchVerificationBody): Promise<[string | null, string?]> => {
	try {
		const patchedVerificationResponse = await makeRequest<PatchVerificationBody, string>({
			method: "PATCH",
			url: `${API_URL}/verification`,
			body,
			useToken: true,
		});

		return [patchedVerificationResponse];
	} catch (nativeError) {
		const [error] = parseAxiosError(nativeError);

		return [null, `Ошибка изменения верификации. ${error}`];
	}
};
