import { TableCell, TableRow, useTheme } from "@mui/material";
import { DiscountTooltip } from "./DiscountTooltip";
import { Discount, TariffCartData } from "@frontend/kitui";
import { currencyFormatter } from "@root/utils/currencyFormatter";
import { useEffect } from "react";

interface Props {
	tariffCartData: TariffCartData;
	appliedDiscounts: Discount[];
}

export default function CartItemRow({ tariffCartData, appliedDiscounts }: Props) {
	const theme = useTheme();

	useEffect(() => {
		if (tariffCartData.privileges.length > 1) {
			console.warn(`Количество привилегий в тарифе ${tariffCartData.name}(${tariffCartData.id}) больше одного`);
		}
	}, [tariffCartData.id, tariffCartData.name, tariffCartData.privileges.length]);

	return (
		<TableRow
			key={tariffCartData.id}
			sx={{
				borderBottom: "2px solid",
				borderColor: theme.palette.grayLight.main,
				".MuiTableCell-root": {
					color: theme.palette.secondary.main,
				},
			}}
		>
			<TableCell>{tariffCartData.name}</TableCell>
			<TableCell>{tariffCartData.privileges[0].description}</TableCell>
			<TableCell>
				{appliedDiscounts.map((discount, index, arr) => (
					<span key={discount.ID}>
						<DiscountTooltip discount={discount} />
						{index < arr.length - 1 && <span>,&nbsp;</span>}
					</span>
				))}
			</TableCell>
			<TableCell>{currencyFormatter.format(tariffCartData.price / 100)}</TableCell>
		</TableRow>
	);
}
