import { useState } from "react";
import {
	Button,
	Checkbox,
	FormControl,
	ListItemText,
	MenuItem,
	Select,
	SelectChangeEvent,
	TextField,
} from "@mui/material";
import { MOCK_DATA_USERS } from "@root/api/roles";
import { deleteRole } from "@root/api/roles";
import { enqueueSnackbar } from "notistack";

const ITEM_HEIGHT = 48;
const ITEM_PADDING_TOP = 8;
const MenuProps = {
	PaperProps: {
		style: {
			maxHeight: ITEM_HEIGHT * 4.5 + ITEM_PADDING_TOP,
		},
	},
};

export default function DeleteForm() {
	const [personName, setPersonName] = useState<string[]>([]);
	const [roleId, setRoleId] = useState<string>();

	const handleChange = (event: SelectChangeEvent<typeof personName>) => {
		const {
			target: { value },
		} = event;
		setPersonName(typeof value === "string" ? value.split(",") : value);
	};

	const rolesDelete = async (id = "") => {
		const [_, deletedRoleError] = await deleteRole(id);

		if (deletedRoleError) {
			return enqueueSnackbar(deletedRoleError);
		}
	};

	return (
		<>
			<Button onClick={() => rolesDelete(roleId)} sx={{ mr: "5px", bgcolor: "#fe9903", color: "white" }}>
				Удалить
			</Button>
			<TextField
				placeholder="название"
				fullWidth
				sx={{
					alignItems: "center",
					maxWidth: "400px",
					width: "100%",
					"& .MuiInputBase-root": {
						backgroundColor: "#F2F3F7",
						height: "48px",
					},
				}}
				inputProps={{
					sx: {
						borderRadius: "10px",
						fontSize: "18px",
						lineHeight: "21px",
						py: 0,
					},
				}}
			/>
			<FormControl sx={{ ml: "25px", width: "80%" }}>
				<Select
					sx={{ bgcolor: "white", height: "48px" }}
					labelId="demo-multiple-checkbox-label"
					id="demo-multiple-checkbox"
					value={personName}
					onChange={handleChange}
					renderValue={(selected) => selected.join(", ")}
					MenuProps={MenuProps}
				>
					{MOCK_DATA_USERS.map(({ name, id }) => (
						<MenuItem key={id} value={name}>
							<Checkbox onClick={() => setRoleId(id)} checked={personName.indexOf(name) > -1} />
							<ListItemText primary={name} />
						</MenuItem>
					))}
				</Select>
			</FormControl>
		</>
	);
}
