import { enqueueSnackbar } from "notistack";
import { GridSelectionModel } from "@mui/x-data-grid";
import { Box, Button, useMediaQuery, useTheme } from "@mui/material";

import { changeDiscount } from "@root/api/discounts/requests";
import { findDiscountsById } from "@root/stores/discounts";

import { requestDiscounts } from "@root/services/discounts.service";
import { mutate } from "swr";

interface Props {
	selectedRows: GridSelectionModel;
}
export default function DiscountDataGrid({ selectedRows }: Props) {
	const theme = useTheme();
	const mobile = useMediaQuery(theme.breakpoints.down(400));
	const changeData = async (isActive: boolean) => {
		let done = 0;
		let fatal = 0;

		for (const id of selectedRows) {
			const discount = findDiscountsById(String(id));

			if (!discount) {
				return enqueueSnackbar("Скидка не найдена");
			}

			const [, changedDiscountError] = await changeDiscount(String(id), {
				...discount,
				Deprecated: isActive,
			});

			if (changedDiscountError) {
				done += 1;
			} else {
				fatal += 1;
			}
			mutate("discounts");
		}

		await requestDiscounts();

		if (done) {
			enqueueSnackbar("Успешно изменён статус " + done + " скидок");
		}

		if (fatal) {
			enqueueSnackbar(fatal + " скидок не изменили статус");
		}
	};

	return (
		<Box
			sx={{
				width: mobile ? "250px" : "400px",
				display: "flex",
				justifyContent: "space-between",
				flexDirection: mobile ? "column" : undefined,
				gap: "10px",
			}}
		>
			<Button onClick={() => changeData(false)}>Активировать</Button>
			<Button onClick={() => changeData(true)}>Деактивировать</Button>
		</Box>
	);
}
