import { Box, Checkbox, TextField, Typography, useTheme } from "@mui/material";
import { DesktopDatePicker } from "@mui/x-date-pickers/DesktopDatePicker";
import { useState } from "react";

export default function DatePickers() {
	const theme = useTheme();
	const [isInfinite, setIsInfinite] = useState<boolean>(false);
	const [startDate, setStartDate] = useState<Date>(new Date());
	const [endDate, setEndDate] = useState<Date>(new Date());

	return (
		<>
			<Typography
				variant="h4"
				sx={{
					width: "90%",
					height: "40px",
					fontWeight: "normal",
					color: theme.palette.grayDisabled.main,
					marginTop: "55px",
				}}
			>
				Дата действия:
			</Typography>
			<Box
				sx={{
					width: "100%",
					display: "flex",
					flexWrap: "wrap",
				}}
			>
				<Typography
					sx={{
						width: "35px",
						display: "flex",
						flexDirection: "column",
						justifyContent: "center",
						alignItems: "left",
					}}
				>
					С
				</Typography>
				<DesktopDatePicker
					inputFormat="DD/MM/YYYY"
					value={startDate}
					onChange={(e) => {
						if (e) {
							setStartDate(e);
						}
					}}
					renderInput={(params) => <TextField {...params} />}
					InputProps={{
						sx: {
							height: "40px",
							color: theme.palette.secondary.main,
							border: "1px solid",
							borderColor: theme.palette.secondary.main,
							"& .MuiSvgIcon-root": { color: theme.palette.secondary.main },
						},
					}}
				/>
				<Typography
					sx={{
						width: "65px",
						display: "flex",
						flexDirection: "column",
						justifyContent: "center",
						alignItems: "center",
					}}
				>
					по
				</Typography>
				<DesktopDatePicker
					inputFormat="DD/MM/YYYY"
					value={endDate}
					onChange={(e) => {
						if (e) {
							setEndDate(e);
						}
					}}
					renderInput={(params) => <TextField {...params} />}
					InputProps={{
						sx: {
							height: "40px",
							color: theme.palette.secondary.main,
							border: "1px solid",
							borderColor: theme.palette.secondary.main,
							"& .MuiSvgIcon-root": { color: theme.palette.secondary.main },
						},
					}}
				/>
			</Box>
			<Box
				sx={{
					display: "flex",
					width: "90%",
					marginTop: theme.spacing(2),
				}}
			>
				<Box
					sx={{
						width: "20px",
						height: "42px",
						display: "flex",
						flexDirection: "column",
						justifyContent: "left",
						alignItems: "left",
						marginRight: theme.spacing(1),
					}}
				>
					<Checkbox
						sx={{
							color: theme.palette.secondary.main,
							"&.Mui-checked": {
								color: theme.palette.secondary.main,
							},
						}}
						checked={isInfinite}
						onClick={() => setIsInfinite((p) => !p)}
					/>
				</Box>
				<Box
					sx={{
						display: "flex",
						flexDirection: "column",
						justifyContent: "center",
						alignItems: "center",
					}}
				>
					Бессрочно
				</Box>
			</Box>
		</>
	);
}
