import { Box, TextField, Typography, useTheme } from "@mui/material";
import { DatePicker } from "@mui/x-date-pickers";

import type { Moment } from "moment";

type DateFilterProps = {
	from: Moment | null;
	to: Moment | null;
	setFrom: (date: Moment | null) => void;
	setTo: (date: Moment | null) => void;
};

export const DateFilter = ({ to, setTo, from, setFrom }: DateFilterProps) => {
	const theme = useTheme();

	return (
		<>
			<Box>
				<Typography
					sx={{
						fontSize: "16px",
						marginBottom: "5px",
						fontWeight: 500,
						color: "4D4D4D",
					}}
				>
					Дата начала
				</Typography>
				<DatePicker
					inputFormat="DD/MM/YYYY"
					value={from}
					onChange={(date) => date && setFrom(date.startOf("day"))}
					renderInput={(params) => <TextField {...params} sx={{ background: "#1F2126", borderRadius: "5px" }} />}
					InputProps={{
						sx: {
							height: "40px",
							color: theme.palette.secondary.main,
							border: "1px solid",
							borderColor: theme.palette.secondary.main,
							"& .MuiSvgIcon-root": { color: theme.palette.secondary.main },
						},
					}}
				/>
			</Box>
			<Box>
				<Typography
					sx={{
						fontSize: "16px",
						marginBottom: "5px",
						fontWeight: 500,
						color: "4D4D4D",
					}}
				>
					Дата окончания
				</Typography>
				<DatePicker
					inputFormat="DD/MM/YYYY"
					value={to}
					onChange={(date) => date && setTo(date.endOf("day"))}
					renderInput={(params) => <TextField {...params} sx={{ background: "#1F2126", borderRadius: "5px" }} />}
					InputProps={{
						sx: {
							height: "40px",
							color: theme.palette.secondary.main,
							border: "1px solid",
							borderColor: theme.palette.secondary.main,
							"& .MuiSvgIcon-root": {
								color: theme.palette.secondary.main,
							},
						},
					}}
				/>
			</Box>
		</>
	);
};
