import { useState } from "react";
import moment from "moment";
import { Table, TableBody, TableCell, TableHead, TableRow, Button, useTheme } from "@mui/material";

import { DateFilter } from "./DateFilter";

import { useQuizStatistic } from "@root/utils/hooks/useQuizStatistic";

import type { Moment } from "moment";

export const QuizInfo = () => {
	const [from, setFrom] = useState<Moment | null>(null);
	const [to, setTo] = useState<Moment | null>(moment());
	const theme = useTheme();
	const { Registrations, Quizes, Results } = useQuizStatistic({
		from,
		to,
	});

	const resetTime = () => {
		setFrom(moment());
		setTo(moment());
	};

	return (
		<>
			<DateFilter from={from} to={to} setFrom={setFrom} setTo={setTo} />
			<Button sx={{ m: "10px 0" }} onClick={resetTime}>
				Сбросить даты
			</Button>
			<Table
				sx={{
					width: "80%",
					border: "2px solid",
					borderColor: theme.palette.secondary.main,
					bgcolor: theme.palette.content.main,
					color: "white",
				}}
			>
				<TableHead>
					<TableRow
						sx={{
							borderBottom: "2px solid",
							borderColor: theme.palette.grayLight.main,
							height: "100px",
						}}
					>
						<TableCell sx={{ color: "inherit" }} align="center">
							Регистраций
						</TableCell>
						<TableCell sx={{ color: "inherit" }} align="center">
							Quiz
						</TableCell>
						<TableCell sx={{ color: "inherit" }} align="center">
							Результаты
						</TableCell>
					</TableRow>
				</TableHead>
				<TableBody>
					<TableRow>
						<TableCell sx={{ color: "inherit" }} align="center">
							{Registrations}
						</TableCell>
						<TableCell sx={{ color: "inherit" }} align="center">
							{Quizes}
						</TableCell>
						<TableCell sx={{ color: "inherit" }} align="center">
							{Results}
						</TableCell>
					</TableRow>
				</TableBody>
			</Table>
		</>
	);
};
