import { useState } from "react";
import moment from "moment";
import {
    Box,
    FormControl, MenuItem, Select,
    Table,
    TableBody,
    TableCell,
    TableHead,
    TableRow,
    Typography,
    useTheme,
} from "@mui/material";

import { DateFilter } from "./DateFilter";

import {useAllPromocodes, useNotActivePromocodes} from "@root/api/promocode/swr";
import { usePromocodeStatistics } from "@root/utils/hooks/usePromocodeStatistics";

import type { Moment } from "moment";
import {SelectChangeEvent} from "@mui/material/Select";

type PropStatistic = {
    "id": string,
    "Regs": number,
    "Money": number,
    "codeword": string,
}

export const StatisticsPromocode = () => {
  const [from, setFrom] = useState<Moment | null>(
    moment(moment().subtract(4, "weeks"))
  );
  const [to, setTo] = useState<Moment | null>(moment());
  const [active, setActive] = useState(true);
  const promocodes = useAllPromocodes();
  const promocodesNot = useNotActivePromocodes();
  const promocodeStatistics = usePromocodeStatistics({ to, from });
  const theme = useTheme();

   const filterPromo = active ? promocodes : promocodesNot;
  console.log(promocodes, "active");
  console.log(promocodesNot);

    const filteredPromoStatistics = () => {
        const copyPromocodeStatistics:PropStatistic[] = [];
      Object.entries(promocodeStatistics).map(([key, { Regs, Money }]) => {

        for(const i in filterPromo){
          if(filterPromo[i].id === key) {
              copyPromocodeStatistics.push(
                  {
                      "id": key,
                      "Regs": Regs,
                      "Money": Money,
                      "codeword": filterPromo[i].codeword,
                  }
              );

        }}

      });
        return copyPromocodeStatistics;
  };

const filteredStat = filteredPromoStatistics();

  return (
    <>
      <Typography sx={{ marginTop: "30px" }}>Статистика промокодов</Typography>
      <DateFilter from={from} to={to} setFrom={setFrom} setTo={setTo} />
        <Box sx={{marginTop: "55px",  width: "80%", display: "flex"}}>
            <FormControl variant="standard" sx={{ m: 1, minWidth: 120 }}>
                <Select
                    labelId="demo-simple-select-standard-label"
                    id="demo-simple-select-standard"
                    sx={{color: "white",
                        backgroundColor: "transparent",
                        padding: "5px",
                        border: "1px solid white",
                        borderRadius: "4px",
                        ".MuiSelect-icon": {
                            color: "white"
                        }
                    }}
                    value={active? "true" : "false"}
                    onChange={(event: SelectChangeEvent) => {
                        setActive((event.target.value) === "true" ? true : false);
                    }}
                    label="Age"
                >
                    <MenuItem value={"true"}>Активные</MenuItem>
                    <MenuItem value={"false"}>Неактивные</MenuItem>
                </Select>
            </FormControl>
        </Box>
      <Table
        sx={{
          width: "80%",
          border: "2px solid",
          borderColor: theme.palette.secondary.main,
          bgcolor: theme.palette.content.main,
          color: "white",
          marginTop: "30px",
        }}
      >
        <TableHead>
          <TableRow
            sx={{
              borderBottom: "2px solid",
              borderColor: theme.palette.grayLight.main,
              height: "100px",
            }}
          >
            <TableCell sx={{ color: "inherit" }} align="center">
              Промокод
            </TableCell>
            <TableCell sx={{ color: "inherit" }} align="center">
              Регистации
            </TableCell>
            <TableCell sx={{ color: "inherit" }} align="center">
              Внесено
            </TableCell>
          </TableRow>
        </TableHead>
        {filteredStat.map((stat) => (
           <TableBody>
            <TableRow>
              <TableCell sx={{ color: "inherit" }} align="center">
                {stat?.codeword}
              </TableCell>
              <TableCell sx={{ color: "inherit" }} align="center">
                {stat?.Regs}
              </TableCell>
              <TableCell sx={{ color: "inherit" }} align="center">
                {(stat?.Money / 100).toFixed(2)}
              </TableCell>
            </TableRow>
          </TableBody>
        ))}
      </Table>
    </>
  );
};
