import Modal from "@mui/material/Modal";
import { closeDeleteTariffDialog } from "@stores/tariffs";
import Box from "@mui/material/Box";
import Typography from "@mui/material/Typography";
import Button from "@mui/material/Button";
import makeRequest from "@root/api/makeRequest";
import { parseAxiosError } from "@root/utils/parse-error";
import { closeTicket } from "@root/api/tickets";
interface Props {
	ticketId: string | undefined;
	openModal: boolean;
	setOpenModal: (a: boolean) => void;
}

export default function CloseTicketModal({ ticketId, openModal, setOpenModal }: Props) {
	const onCloseTicket = async () => {
		if (ticketId) {
			await closeTicket(ticketId);
			setOpenModal(false);
		}
	};

	return (
		<Modal
			open={openModal}
			onClose={() => setOpenModal(false)}
			aria-labelledby="modal-modal-title"
			aria-describedby="modal-modal-description"
		>
			<Box
				sx={{
					position: "absolute",
					top: "50%",
					left: "50%",
					transform: "translate(-50%, -50%)",
					width: 400,
					bgcolor: "background.paper",
					border: "2px solid gray",
					borderRadius: "6px",
					boxShadow: 24,
					p: 4,
				}}
			>
				<Typography id="modal-modal-title" variant="h6" component="h2">
					Вы уверены, что хотите закрыть тикет?
				</Typography>
				<Box
					sx={{
						mt: "20px",
						display: "flex",
						width: "332px",
						justifyContent: "space-between",
						alignItems: "center",
					}}
				>
					<Button onClick={onCloseTicket} sx={{ width: "40px", height: "25px" }}>
						Да
					</Button>
					<Button onClick={() => setOpenModal(false)} sx={{ width: "40px", height: "25px" }}>
						Нет
					</Button>
				</Box>
			</Box>
		</Modal>
	);
}
