import CircleIcon from "@mui/icons-material/Circle";
import { Box, Card, CardActionArea, CardContent, CardHeader, Divider, Typography, useTheme } from "@mui/material";
import { green } from "@mui/material/colors";
import { Ticket } from "@root/model/ticket";
import { useNavigate, useParams } from "react-router-dom";

const flexCenterSx = {
	textAlign: "center",
	display: "flex",
	justifyContent: "center",
	alignItems: "center",
	padding: "10px",
};

interface Props {
	ticket: Ticket;
	setActiveUserId: (userId: string) => void;
}

export default function TicketItem({ ticket, setActiveUserId }: Props) {
	const theme = useTheme();
	const navigate = useNavigate();
	const ticketId = useParams().ticketId;

	console.log(ticket)
	const isUnread = ticket.user === ticket?.top_message?.user_id;
	const isSelected = ticket.id === ticketId;

	const unreadSx = {
		border: "1px solid",
		borderColor: ticket.system ? "red" : theme.palette.golden.main,
		backgroundColor: theme.palette.goldenMedium.main,
	};

	const selectedSx = {
		border: `2px solid ${theme.palette.secondary.main}`,
	};

	function handleCardClick() {
		navigate(`/support/${ticket.id}`);
	}

	return (
		<Card
			sx={{
				minHeight: "70px",
				backgroundColor: "transparent",
				color: "white",
				...(isUnread && unreadSx),
				...(isSelected && selectedSx),
			}}
		>
			<CardActionArea onClick={handleCardClick}>
				<CardHeader
					title={<Typography>{ticket.title}</Typography>}
					disableTypography
					sx={{
						textAlign: "center",
						p: "4px",
					}}
				/>
				<Divider />
				<CardContent
					sx={{
						display: "flex",
						justifyContent: "space-between",
						backgroundColor: "transparent",
						p: 0,
					}}
				>
					<Box sx={flexCenterSx}>{new Date(ticket.top_message.created_at).toLocaleDateString()}</Box>
					<Box
						sx={{
							...flexCenterSx,
							overflow: "hidden",
							whiteSpace: "nowrap",
							display: "block",
							flexGrow: 1,
						}}
					>
						{ticket.top_message.message}
					</Box>
					<Box sx={flexCenterSx}>
						<CircleIcon
							sx={{
								color: green[700],
								transform: "scale(0.8)",
							}}
						/>
					</Box>
					<Box sx={flexCenterSx} onClick={() => setActiveUserId(ticket.user)}>
						ИНФО
					</Box>
				</CardContent>
			</CardActionArea>
		</Card>
	);
}
