import { GridColDef } from "@mui/x-data-grid";
import DataGrid from "@kitUI/datagrid";
import { Tooltip, IconButton } from "@mui/material";
import { usePrivilegeStore } from "@root/stores/privilegesStore";
import AutorenewIcon from "@mui/icons-material/Autorenew";
import { requestPrivileges } from "@root/services/privilegies.service";
import { currencyFormatter } from "@root/utils/currencyFormatter";

const columns: GridColDef[] = [
	{ field: "id", headerName: "id", width: 150 },
	{ field: "name", headerName: "Привелегия", width: 150 },
	{ field: "description", headerName: "Описание", width: 550 }, //инфо из гитлаба.
	{ field: "type", headerName: "Тип", width: 150 },
	{ field: "price", headerName: "Стоимость", width: 100 },
];

export default function Privileges() {
	const privileges = usePrivilegeStore((state) => state.privileges);
	const privilegesGridData = privileges
		.filter((privilege) => !privilege.isDeleted)
		.map((privilege) => ({
			id: privilege.privilegeId,
			name: privilege.name,
			description: privilege.description,
			type: privilege.type,
			price: currencyFormatter.format(privilege.price / 100),
		}));

	return (
		<>
			<Tooltip title="обновить список привилегий">
				<IconButton onClick={requestPrivileges}>
					<AutorenewIcon sx={{ color: "white" }} />
				</IconButton>
			</Tooltip>
			<DataGrid rows={privilegesGridData} columns={columns} />
		</>
	);
}
