import { GridColDef, GridToolbar } from "@mui/x-data-grid";
import { Box, Button, IconButton, Tooltip } from "@mui/material";
import BackspaceIcon from "@mui/icons-material/Backspace";
import ModeEditOutlineOutlinedIcon from "@mui/icons-material/ModeEditOutlineOutlined";
import DataGrid from "@kitUI/datagrid";
import DeleteModal from "@root/pages/dashboard/Content/Tariffs/DeleteModal";
import EditModal from "./EditModal";
import AutorenewIcon from "@mui/icons-material/Autorenew";
import { requestTariffs } from "@root/services/tariffs.service";
import {
	openDeleteTariffDialog,
	openEditTariffDialog,
	setSelectedTariffIds,
	useTariffStore,
} from "@root/stores/tariffs";
import { Tariff } from "@frontend/kitui";
import { getTariffPrice } from "@root/utils/tariffPrice";
import { currencyFormatter } from "@root/utils/currencyFormatter";

const columns: GridColDef<Tariff, string | number>[] = [
	{ field: "_id", headerName: "ID", width: 100, valueGetter: ({ row }) => row.order || 1 },
	{
		field: "edit",
		headerName: "Изменение",
		width: 60,
		renderCell: ({ row }) => {
			return (
				<IconButton onClick={() => openEditTariffDialog(row._id)}>
					<ModeEditOutlineOutlinedIcon />
				</IconButton>
			);
		},
	},
	{ field: "name", headerName: "Название тарифа", width: 150, valueGetter: ({ row }) => row.name },
	{ field: "amount", headerName: "Количество", width: 110, valueGetter: ({ row }) => row.privileges[0].amount },
	{ field: "serviceName", headerName: "Сервис", width: 150, valueGetter: ({ row }) => row.privileges[0].serviceKey },
	{ field: "privilegeName", headerName: "Привилегия", width: 150, valueGetter: ({ row }) => row.privileges[0].name },
	{ field: "type", headerName: "Единица", width: 100, valueGetter: ({ row }) => row.privileges[0].type },
	{
		field: "pricePerUnit",
		headerName: "Цена за ед.",
		width: 100,
		valueGetter: ({ row }) => currencyFormatter.format(row.privileges[0].price / 100),
	},
	{
		field: "isCustom",
		headerName: "Кастомная цена",
		width: 130,
		valueGetter: ({ row }) => (row.isCustom ? "Да" : "Нет"),
	},
	{
		field: "total",
		headerName: "Сумма",
		width: 100,
		valueGetter: ({ row }) => currencyFormatter.format(getTariffPrice(row) / 100),
	},
	{
		field: "delete",
		headerName: "Удаление",
		width: 60,
		renderCell: ({ row }) => {
			return (
				<IconButton onClick={() => openDeleteTariffDialog([row._id])}>
					<BackspaceIcon />
				</IconButton>
			);
		},
	},
];

export default function TariffsDG() {
	const tariffs = useTariffStore((state) => state.tariffs);
	const selectedTariffIds = useTariffStore((state) => state.selectedTariffIds);

	return (
		<>
			<Tooltip title="обновить список тарифов">
				<IconButton onClick={() => requestTariffs()}>
					<AutorenewIcon sx={{ color: "white" }} />
				</IconButton>
			</Tooltip>
			<DataGrid
				className="tariffs-data-grid"
				disableSelectionOnClick={true}
				checkboxSelection={true}
				rows={tariffs}
				columns={columns}
				getRowId={(row) => row._id}
				components={{ Toolbar: GridToolbar }}
				onSelectionModelChange={setSelectedTariffIds}
				sx={{
					minHeight: "600px",
				}}
			/>
			{selectedTariffIds.length ? (
				<Box
					component="section"
					sx={{
						width: "100%",
						display: "flex",
						justifyContent: "start",
						mb: "30px",
					}}
				>
					<Button
						onClick={() => openDeleteTariffDialog(selectedTariffIds.map((s) => s.toString()))}
						sx={{ mr: "20px", zIndex: "10000" }}
					>
						Удалить выделенные
					</Button>
				</Box>
			) : null}
			<DeleteModal />
			<EditModal />
		</>
	);
}
