import { updateTariffs } from "@root/stores/tariffs";
import { requestTariffs as requestTariffsRequest } from "@root/api/tariffs";

import type { Tariff } from "@frontend/kitui";

const mutateTariffs = (tariffs: Tariff[]) => {
	const nonDeletedTariffs = tariffs.filter(({ isDeleted }) => !isDeleted);

	updateTariffs(nonDeletedTariffs);
};

export const requestTariffs = async (page: number = 1, existingTariffs: Tariff[] = []): Promise<void> => {
	const [tariffsResponse, tariffsResponseError] = await requestTariffsRequest(page);

	if (tariffsResponseError) {
		console.error(tariffsResponseError);

		return;
	}

	if (tariffsResponse) {
		if (page < tariffsResponse.totalPages) {
			return requestTariffs(page + 1, [...existingTariffs, ...tariffsResponse.tariffs]);
		}

		mutateTariffs([...existingTariffs, ...tariffsResponse.tariffs]);
	}
};
