import { GridSelectionModel } from "@mui/x-data-grid";
import { create } from "zustand";
import { devtools } from "zustand/middleware";
import { produce } from "immer";
import { Discount } from "@frontend/kitui";

interface DiscountStore {
	discounts: Discount[];
	selectedDiscountIds: GridSelectionModel;
	editDiscountId: string | null;
}

export const useDiscountStore = create<DiscountStore>()(
	devtools(
		(set, get) => ({
			discounts: [],
			selectedDiscountIds: [],
			editDiscountId: null,
		}),
		{
			name: "Discount",
			enabled: process.env.NODE_ENV === "development",
		}
	)
);

export const setDiscounts = (discounts: DiscountStore["discounts"]) => useDiscountStore.setState({ discounts });

export const findDiscountsById = (discountId: string): Discount | null =>
	useDiscountStore.getState().discounts.find((discount) => discount.ID === discountId) ?? null;

export const addDiscount = (discount: DiscountStore["discounts"][number]) =>
	useDiscountStore.setState((state) => ({ discounts: [...state.discounts, discount] }));

export const updateDiscount = (updatedDiscount: DiscountStore["discounts"][number]) =>
	useDiscountStore.setState(
		produce<DiscountStore>((state) => {
			const discountIndex = state.discounts.findIndex((discount) => discount.ID === updatedDiscount.ID);
			if (discountIndex === -1) throw new Error(`Discount not found when updating: ${updatedDiscount.ID}`);

			state.discounts.splice(discountIndex, 1, updatedDiscount);
		})
	);

export const setSelectedDiscountIds = (selectedDiscountIds: DiscountStore["selectedDiscountIds"]) =>
	useDiscountStore.setState({ selectedDiscountIds });

export const openEditDiscountDialog = (editDiscountId: DiscountStore["editDiscountId"]) =>
	useDiscountStore.setState({ editDiscountId });

export const closeEditDiscountDialog = () => useDiscountStore.setState({ editDiscountId: null });
