import { create } from "zustand";
import { devtools } from "zustand/middleware";
import { CustomPrivilege } from "@frontend/kitui";

interface PrivilegeStore {
	privileges: CustomPrivilege[];
}

export const usePrivilegeStore = create<PrivilegeStore>()(
	devtools(
		(set, get) => ({
			privileges: [],
		}),
		{
			name: "Privileges",
			enabled: process.env.NODE_ENV === "development",
		}
	)
);

export const resetPrivilegeArray = (privileges: PrivilegeStore["privileges"]) =>
	usePrivilegeStore.setState({ privileges });

export const findPrivilegeById = (privilegeId: string) => {
	return (
		usePrivilegeStore
			.getState()
			.privileges.find((privilege) => privilege._id === privilegeId || privilege.privilegeId === privilegeId) ?? null
	);
};
