import { FetchState } from "@frontend/kitui";
import { Ticket } from "@root/model/ticket";
import { create } from "zustand";
import { devtools } from "zustand/middleware";

interface TicketStore {
	tickets: Ticket[];
	apiPage: number;
	ticketsPerPage: number;
	ticketsFetchState: FetchState;
}

export const useTicketStore = create<TicketStore>()(
	devtools(
		(set, get) => ({
			tickets: [],
			apiPage: 0,
			ticketsPerPage: 20,
			ticketsFetchState: "idle",
		}),
		{
			name: "Tickets",
			enabled: process.env.NODE_ENV === "development",
		}
	)
);

export const incrementTicketsApiPage = () => {
	const state = useTicketStore.getState();

	useTicketStore.setState({ apiPage: state.apiPage + 1 });
};

export const updateTickets = (receivedTickets: Ticket[]) => {
	const state = useTicketStore.getState();
	const ticketIdToTicketMap: { [ticketId: string]: Ticket } = {};

	[...state.tickets, ...receivedTickets].forEach((ticket) => (ticketIdToTicketMap[ticket.id] = ticket));

	useTicketStore.setState({ tickets: Object.values(ticketIdToTicketMap) });
};

export const clearTickets = () => useTicketStore.setState({ tickets: [] });

export const setTicketsFetchState = (ticketsFetchState: FetchState) => useTicketStore.setState({ ticketsFetchState });
