import { useEffect } from "react";

import { requestPrivileges } from "@root/api/privilegies";

import type { CustomPrivilege } from "@frontend/kitui";

export default function usePrivileges({
	onError,
	onNewPrivileges,
}: {
	onNewPrivileges: (response: CustomPrivilege[]) => void;
	onError?: (error: any) => void;
}) {
	useEffect(() => {
		const controller = new AbortController();

		requestPrivileges(controller.signal).then(([privilegesResponse, privilegesError]) => {
			if (privilegesError) {
				return onError?.(privilegesError);
			}
			onNewPrivileges(privilegesResponse);
		});

		return () => controller.abort();
	}, [onError, onNewPrivileges]);
}
