import { useEffect, useState } from "react";
import { getStatisticsPromocode } from "@root/api/quizStatistics";

import type { Moment } from "moment";
import type { AllPromocodeStatistics } from "@root/api/quizStatistics/types";
import moment from "moment";

interface useStatisticProps {
	to: Moment | null;
	from: Moment | null;
}

export function usePromocodeStatistics({ to, from }: useStatisticProps) {
	const formatTo = to?.unix();
	const formatFrom = from?.unix() || moment().unix() - 604800;

	const [promocodeStatistics, setPromocodeStatistics] = useState<Record<string, AllPromocodeStatistics>>({});

	useEffect(() => {
		const requestStatistics = async () => {
			const [gottenData] = await getStatisticsPromocode(Number(formatFrom), Number(formatTo));

			if (gottenData) {
				setPromocodeStatistics(gottenData);
			}
		};

		requestStatistics();
	}, [formatTo, formatFrom]);

	return promocodeStatistics;
}
